@@ -141,6 +141,7 @@ typedef struct {
   // Window
   int cols, rows;
   int scrollback_lines;
+  int max_scrollback_lines;
   char scrollbar;
   char scroll_mod;
   bool pgupdn_scroll;
@@ -161,6 +162,7 @@ typedef struct {
   bool bell_taskbar; // xterm: bellIsUrgent
   bool bell_popup;   // xterm: popOnBell
   int bell_interval;
+  int play_tone;
   wstring printer;
   bool confirm_exit;
   // Command line
@@ -218,6 +220,7 @@ typedef struct {
   string menu_title_ctrl_r;
   int geom_sync;
   int tabbar;
+  int new_tabs;
   int col_spacing, row_spacing;
   int auto_leading;
   int padding;
